@@ -1359,7 +1359,7 @@ class UnionArray(UnionMeta[Content], Content):
             parameters=self._parameters,
             mergebool=True,
         )
-        if simplified.length == 0:
+        if simplified.length is not unknown_length and simplified.length == 0:
             return ak.contents.NumpyArray(
                 self._backend.nplike.empty(0, dtype=np.int64),
                 parameters=None,
@@ -1374,7 +1374,7 @@ class UnionArray(UnionMeta[Content], Content):
         )
 
     def _sort_next(self, negaxis, starts, parents, outlength, ascending, stable):
-        if self.length == 0:
+        if self.length is not unknown_length and self.length == 0:
             return self
 
         simplified = type(self).simplified(
@@ -1384,7 +1384,7 @@ class UnionArray(UnionMeta[Content], Content):
             parameters=self._parameters,
             mergebool=True,
         )
-        if simplified.length == 0:
+        if simplified.length is not unknown_length and simplified.length == 0:
             return simplified
 
         if isinstance(simplified, ak.contents.UnionArray):
